summaryrefslogtreecommitdiffstats
path: root/kxsldbg/kxsldbg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kxsldbg/kxsldbg.h')
-rw-r--r--kxsldbg/kxsldbg.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kxsldbg/kxsldbg.h b/kxsldbg/kxsldbg.h
index 1d3ee6c6..5eb95600 100644
--- a/kxsldbg/kxsldbg.h
+++ b/kxsldbg/kxsldbg.h
@@ -48,14 +48,14 @@ protected:
* This method is called when it is time for the app to save its
* properties for session management purposes.
*/
- void saveProperties(KConfig *);
+ void saveProperties(TDEConfig *);
/**
* This method is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- void readProperties(KConfig *);
+ void readProperties(TDEConfig *);
virtual bool closeURL();
@@ -48,14 +48,14 @@ protected:
/**
- * This method is called when this app is restored. The KConfig
+ * This method is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties